pub struct EightBytes { /* private fields */ }Expand description
This is an implementation of a double-ended buffer containing byte values with storage size of 8. Single threaded usage is intended.
Implementations
Sourceimpl EightBytes
Implementation of EightBytes
impl EightBytes
Implementation of EightBytes
Sourcepub fn new() -> EightBytes
pub fn new() -> EightBytes
Creates a new EightBytes.
Sourcepub fn clear(&mut self)
pub fn clear(&mut self)
Clears the contents of this EightBytes. The number of elements would become zero.
Sourcepub fn push_back(&mut self, v: u8)
pub fn push_back(&mut self, v: u8)
Push a value to the back of the buffer. No action performed if buffer is full.
Arguments
v- byte value to be pushed
Sourcepub fn push_front(&mut self, v: u8)
pub fn push_front(&mut self, v: u8)
Push a value to the front of the buffer. No action performed if buffer is full.
Arguments
v- byte value to be pushed
Sourcepub fn pop_front(&mut self) -> Option<u8>
pub fn pop_front(&mut self) -> Option<u8>
Removes the first element and return it. ‘None’ is returned if buffer is empty.
Sourcepub fn pop_back(&mut self) -> Option<u8>
pub fn pop_back(&mut self) -> Option<u8>
Removes the last element and return it. ‘None’ is returned if buffer is empty.
Sourcepub fn peek_at(&self, index: usize) -> Option<u8>
pub fn peek_at(&self, index: usize) -> Option<u8>
Returns the byte at the ‘index’ position without removing it from the collection. The zeroth item is the oldest item from the collection.